//do-file for "Panel data analysis"
//use BritishHouseholdPanel.dta

xtset id year
tab year
xtdescribe

reg mental age woman couple separated divorced never_married  // OLS regression

net sj 3-2 st0039
net install st0039  //installs Wooldridge's test for autocorrelation

xtserial mental age woman couple separated divorced never_married  // runs Wooldridge's test for autocorrelation in panel data

quietly reg mental age woman couple separated divorced never_married
predict Pmental
gen Rmental=mental-Pmental
scatter Rmental Pmental //graphs the residuals against the fitted values

hettest //Breusch-Pagan/Cook-Weisberg test for heteroskedasticity

regress mental age woman couple separated divorced never_married, vce(cluster id) // regression using the robust and cluster options

quietly regress mental age woman couple separated divorced never_married
collapse (mean) mental age woman couple separated divorced never_married if e(sample), by(id)  // this alters the data structure
regress mental age woman couple separated divorced never_married // between effects model
clear

//use BritishHouseholdPanel.dta (do not save data after the above operation)

xtreg mental age woman couple separated divorced never_married, be // between effects model without altering the data structure

quietly xtreg mental age woman couple separated divorced never_married, fe
estimates store fixed
quietly xtreg mental age woman couple separated divorced never_married, re
estimates store random
hausman fixed random // Hausman test for model efficiency


//use Happiness.dta

generate Dbob=id==1 if !missing(id)
generate Dsarah=id==2 if !missing(id)
generate Dpeter=id==3 if !missing(id)
generate Dnicole=id==4 if !missing(id)

regress happiness Dsarah Dpeter Dnicole income1000

gen Bob = -4.107029 + 0.0824934*income1000
gen Sarah = -4.107029 + 5.111141 + 0.0824934
gen Peter = -4.107029 + 4.226857 + 0.0824934
gen Nicole = -4.107029 + 9.410411 + 0.0824934
graph twoway line Bob income1000 || line Sarah income1000 || line Peter income1000 || line Nicole income1000 // fixed effects model 

reg happinessDM income1000DM // analogous fixed effects model

reg happiness income1000 // OLS regression

xtset id
xtreg happiness income1000, fe // fixed effects model


//use BritishHouseholdPanel.dta

xtset id
xtreg mental age woman couple separated divorced never_married, fe // fixed effects model

xtset year
xtreg mental age woman couple separated divorced never_married, fe // time fixed effects

xtset id
xtreg mental age couple separated divorced never_married i.year, fe	//time- and unit fixed effects

xtset id
xtreg mental age woman couple separated divorced never_married, re // random effects


//use TimeSeriesCrossSection.dta

tsset cow year

tab cow
duplicates report cow year  // reports duplicates
duplicates list cow year
duplicates tag cow year, gen(isdup)
edit if isdup

sum FDI, detail

gen lnFDI=ln(FDI) // generating log transformed variable
sum lnFDI, detail

tsline lnFDI if cow<100, by(ccode)
tsline lnFDI if cow>=200 & cow<400, by(ccode)
tsline lnFDI if cow>=400 & cow<600, by(ccode)
tsline lnFDI if cow>=600, by(ccode)

dfuller lnFDI if cow==20, lags(1)  // Dickey-Fuller test
dfuller lnFDI if cow==20, lags(1) regress

corrgram lnFDI if cow==20, lags(10)

ac lnFDI if cow==20, lags(10)

regress lnFDI l.lnFDI l.GDPperCapita l.GDPGrowth ethfrac l.incidence, vce(cluster cow) // regression 

tab onset2

logit onset2 l.GDPGrowth l.GDPperCapita ethfrac, vce(cluster cow) // Logistic regression

xtlogit onset2 l.GDPGrowth l.GDPperCapita ethfrac  // random effects logit model

tab onset2 if e(sample)

logit onset2 l.incidence l.GDPGrowth l.GDPperCapita ethfrac, vce(cluster cow)

//use btscs.ado (open this in the do-file editor, mark everything and press "Execute Selection")

btscs incidence year cow, g(peaceyears) nspline(3)
logit onset2 peaceyears _spline1 _spline2 _spline3 l.GDPGrowth l.GDPperCapita ethfrac, vce(cluster cow)  // logit regression using peaceyears with splines

//use Formula1.dta

sort id year
xtset id year

xtabond employment, lags(2) vce(robust)							//Arellano-Bond model with 2 lags in Y
xtabond employment, lags(2) vce(robust) maxldep(2)				//Arellano-Bond model, with a maximum of 2 lags in Y used as instruments
xtabond employment GDP F1Race, lags(2) vce(robust) maxldep(2)	//including explanatory variables 
estat abond														//test of uncorrelated errors
xtdpd employment GDP F1Race, dgmmiv(employment)					//general version of xtabond 

ssc install xtabond2											//install xtabond2 
xtabond2 employment l.employment GDP F1Race, gmm(l.employment) noleveleq robust small						//xtabond2 model
xtabond2 employment l.employment GDP F1Race, gmm(l.employment) iv(l.GDP l.F1Race) noleveleq robust small	//xtabond2 including instruments of X-variables

